redvox.tests.common.test_offset_model API documentation
Description: tests for offset model

# Module `redvox.tests.common.test_offset_model`

tests for offset model

Expand source code

    """
    tests for offset model
    """
    import unittest

    import numpy as np

    import redvox.tests as tests
    from redvox.common import offset_model as om
    from redvox.common import file_statistics as fs
    from redvox.common import date_time_utils as dtu
    from redvox.common.io import ReadFilter, index_unstructured

    class OffsetModelTest(unittest.TestCase):
        @classmethod
        def setUpClass(cls) -> None:
            cls.apim_filter = ReadFilter(extensions={".rdvxm"}, station_ids={"0000000001"})
            cls.api900_filter = ReadFilter(extensions={".rdvxz"}, station_ids={"1637650010"})

        def test_model_init(self):
            index = index_unstructured(tests.TEST_DATA_DIR, self.apim_filter)
            stats = fs.extract_stats(index)
            latencies = [st.latency for st in stats]
            offsets = [st.offset for st in stats]
            times = [st.best_latency_timestamp for st in stats]
            start_time = dtu.datetime_to_epoch_microseconds_utc(stats[0].packet_start_dt)
            end_time = dtu.datetime_to_epoch_microseconds_utc(stats[-1].packet_start_dt + stats[-1].packet_duration)
            model = om.OffsetModel(np.array(latencies), np.array(offsets), np.array(times), start_time, end_time)
            self.assertEqual(model.intercept, 3440)
            self.assertEqual(model.slope, 0.0)

        def test_empty_model(self):
            model = om.OffsetModel.empty_model()
            self.assertEqual(model.intercept, 0.)
            self.assertEqual(model.slope, 0.)
            self.assertEqual(model.score, 0.)
            self.assertEqual(model.k_bins, 1)
            self.assertEqual(model.n_samples, 3)
            self.assertEqual(model.mean_latency, 0.0)
            self.assertEqual(model.std_dev_latency, 0.0)

## Classes

`class OffsetModelTest (methodName='runTest')`

  A class whose instances are single test cases.

  By default, the test code itself should be placed in a method named 'runTest'.

  If the fixture may be used for many test cases, create as many test methods as are needed. When instantiating such a TestCase subclass, specify in the constructor arguments the name of the test method that the instance is to execute.

  Test authors should subclass TestCase for their own tests. Construction and deconstruction of the test's environment ('fixture') can be implemented by overriding the 'setUp' and 'tearDown' methods respectively.

  If it is necessary to override the init method, the base class init method must always be called. It is important that subclasses should not change the signature of their init method, since instances of the classes are instantiated automatically by parts of the framework in order to be run.

  When subclassing TestCase, you can set these attributes: * failureException: determines which exception will be raised when the instance's assertion methods fail; test methods raising this exception will be deemed to have 'failed' rather than 'errored'. * longMessage: determines whether long messages (including repr of objects used in assert methods) will be printed on failure in addition to any explicit message passed. * maxDiff: sets the maximum length of a diff in failure messages by assert methods using difflib. It is looked up as an instance attribute so can be configured by individual tests if required.

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  Expand source code

      class OffsetModelTest(unittest.TestCase):
          @classmethod
          def setUpClass(cls) -> None:
              cls.apim_filter = ReadFilter(extensions={".rdvxm"}, station_ids={"0000000001"})
              cls.api900_filter = ReadFilter(extensions={".rdvxz"}, station_ids={"1637650010"})

          def test_model_init(self):
              index = index_unstructured(tests.TEST_DATA_DIR, self.apim_filter)
              stats = fs.extract_stats(index)
              latencies = [st.latency for st in stats]
              offsets = [st.offset for st in stats]
              times = [st.best_latency_timestamp for st in stats]
              start_time = dtu.datetime_to_epoch_microseconds_utc(stats[0].packet_start_dt)
              end_time = dtu.datetime_to_epoch_microseconds_utc(stats[-1].packet_start_dt + stats[-1].packet_duration)
              model = om.OffsetModel(np.array(latencies), np.array(offsets), np.array(times), start_time, end_time)
              self.assertEqual(model.intercept, 3440)
              self.assertEqual(model.slope, 0.0)

          def test_empty_model(self):
              model = om.OffsetModel.empty_model()
              self.assertEqual(model.intercept, 0.)
              self.assertEqual(model.slope, 0.)
              self.assertEqual(model.score, 0.)
              self.assertEqual(model.k_bins, 1)
              self.assertEqual(model.n_samples, 3)
              self.assertEqual(model.mean_latency, 0.0)
              self.assertEqual(model.std_dev_latency, 0.0)

  ### Ancestors

  - unittest.case.TestCase

  ### Static methods

  `def setUpClass() ‑> NoneType`

    Hook method for setting up class fixture before running tests in the class.

    Expand source code

        @classmethod
        def setUpClass(cls) -> None:
            cls.apim_filter = ReadFilter(extensions={".rdvxm"}, station_ids={"0000000001"})
            cls.api900_filter = ReadFilter(extensions={".rdvxz"}, station_ids={"1637650010"})

  ### Methods

  `def test_empty_model(self)`
    Expand source code

        def test_empty_model(self):
            model = om.OffsetModel.empty_model()
            self.assertEqual(model.intercept, 0.)
            self.assertEqual(model.slope, 0.)
            self.assertEqual(model.score, 0.)
            self.assertEqual(model.k_bins, 1)
            self.assertEqual(model.n_samples, 3)
            self.assertEqual(model.mean_latency, 0.0)
            self.assertEqual(model.std_dev_latency, 0.0)

  `def test_model_init(self)`
    Expand source code

        def test_model_init(self):
            index = index_unstructured(tests.TEST_DATA_DIR, self.apim_filter)
            stats = fs.extract_stats(index)
            latencies = [st.latency for st in stats]
            offsets = [st.offset for st in stats]
            times = [st.best_latency_timestamp for st in stats]
            start_time = dtu.datetime_to_epoch_microseconds_utc(stats[0].packet_start_dt)
            end_time = dtu.datetime_to_epoch_microseconds_utc(stats[-1].packet_start_dt + stats[-1].packet_duration)
            model = om.OffsetModel(np.array(latencies), np.array(offsets), np.array(times), start_time, end_time)
            self.assertEqual(model.intercept, 3440)
            self.assertEqual(model.slope, 0.0)